summaryrefslogtreecommitdiff
path: root/src/python/gudhi/cubical_complex.pyx
diff options
context:
space:
mode:
authorMathieuCarriere <mathieu.carriere3@gmail.com>2020-01-16 21:26:02 -0500
committerMathieuCarriere <mathieu.carriere3@gmail.com>2020-01-16 21:26:02 -0500
commit19562b27182dcfa6ed262002c2bc8934382f5a53 (patch)
tree421f73315e9f971c176fb814557ff8af40bb1442 /src/python/gudhi/cubical_complex.pyx
parentc89df405c77bb7270db1a7d8f0e49bc22c1b010d (diff)
get rid of persistence_generators and modified name for cubical complex
Diffstat (limited to 'src/python/gudhi/cubical_complex.pyx')
-rw-r--r--src/python/gudhi/cubical_complex.pyx8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/python/gudhi/cubical_complex.pyx b/src/python/gudhi/cubical_complex.pyx
index 5562e8a7..8ea31486 100644
--- a/src/python/gudhi/cubical_complex.pyx
+++ b/src/python/gudhi/cubical_complex.pyx
@@ -31,7 +31,7 @@ cdef extern from "Persistent_cohomology_interface.h" namespace "Gudhi":
cdef cppclass Cubical_complex_persistence_interface "Gudhi::Persistent_cohomology_interface<Gudhi::Cubical_complex::Cubical_complex_interface<>>":
Cubical_complex_persistence_interface(Bitmap_cubical_complex_base_interface * st, bool persistence_dim_max)
vector[pair[int, pair[double, double]]] get_persistence(int homology_coeff_field, double min_persistence)
- vector[pair[int, pair[pair[double, int], pair[double, int]]]] get_persistence_cubical_generators(int homology_coeff_field, double min_persistence)
+ vector[pair[int, pair[pair[double, int], pair[double, int]]]] get_cofaces_of_cubical_persistence_pairs(int homology_coeff_field, double min_persistence)
vector[int] betti_numbers()
vector[int] persistent_betti_numbers(double from_value, double to_value)
vector[pair[double,double]] intervals_in_dimension(int dimension)
@@ -146,7 +146,7 @@ cdef class CubicalComplex:
persistence_result = self.pcohptr.get_persistence(homology_coeff_field, min_persistence)
return persistence_result
- def persistence_generators(self, homology_coeff_field=11, min_persistence=0, persistence_dim_max = False):
+ def cofaces_of_cubical_persistence_pairs(self, homology_coeff_field=11, min_persistence=0, persistence_dim_max = False):
"""This function returns the persistence of the simplicial complex.
:param homology_coeff_field: The homology coefficient field. Must be a
@@ -161,7 +161,7 @@ cdef class CubicalComplex:
maximal dimension in the complex is computed. If false, it is
ignored. Default is false.
:type persistence_dim_max: bool
:returns: The persistence of the simplicial complex, together with the corresponding generators, i.e., the positive and negative top-dimensional cells.
:rtype: list of pairs(dimension, pair(index of positive top-dimensional cell, index of negative top-dimensional cell))
"""
if self.pcohptr != NULL:
@@ -169,7 +169,7 @@ cdef class CubicalComplex:
self.pcohptr = new Cubical_complex_persistence_interface(self.thisptr, True)
cdef vector[pair[int, pair[pair[double, int], pair[double, int]]]] persistence_result
if self.pcohptr != NULL:
- persistence_result = self.pcohptr.get_persistence_cubical_generators(homology_coeff_field, min_persistence)
+ persistence_result = self.pcohptr.get_cofaces_of_cubical_persistence_pairs(homology_coeff_field, min_persistence)
return persistence_result
def betti_numbers(self):
@@ -161,7 +161,7 @@ cdef class CubicalComplex:
ignored. Default is false.
:type persistence_dim_max: bool
- :returns: The persistence of the simplicial complex, together with the corresponding generators, i.e., the positive and negative top-dimensional cells.
+ :returns: The persistence of the simplicial complex, together with the cofaces of the corresponding generators, i.e., the top-dimensional cells/cofaces of the positive and negative simplices.
:rtype: list of pairs(dimension, pair(index of positive top-dimensional cell, index of negative top-dimensional cell))
"""